==> percona-server-mongodb_4.0.14.orig.tar.gz: percona-server-mongodb-4.0.14-8/src/mongo/tools/perconadecrypt_options.h <==
/*======
This file is part of Percona Server for MongoDB.

Copyright (C) 2019-present Percona and/or its affiliates. All rights reserved.

    This program is free software: you can redistribute it and/or modify
    it under the terms of the Server Side Public License, version 1,
    as published by MongoDB, Inc.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    Server Side Public License for more details.

    You should have received a copy of the Server Side Public License
    along with this program. If not, see
    <http://www.mongodb.com/licensing/server-side-public-license>.

    As a special exception, the copyright holders give permission to link the
    code of portions of this program with the OpenSSL library under certain
    conditions as described in each individual source file and distribute
    linked combinations including the program with the OpenSSL library. You
    must comply with the Server Side Public License in all respects for
    all of the code used other than as permitted herein. If you modify file(s)
    with this exception, you may extend this exception to your version of the
    file(s), but you are not obligated to do so. If you do not wish to do so,
    delete this exception statement from your version. If you delete this
    exception statement from all source files in the program, then also delete
    it in the license file.
======= */

#pragma once

#include <vector>

#include "mongo/base/status.h"

namespace mongo {

namespace optionenvironment {
class OptionSection;
class Environment;
}  // namespace optionenvironment

namespace moe = mongo::optionenvironment;

struct PerconaDecryptGlobalParams {
    std::string inputPath;
    std::string outputPath;

    PerconaDecryptGlobalParams() = default;
};

extern PerconaDecryptGlobalParams perconaDecryptGlobalParams;

Status addPerconaDecryptOptions(moe::OptionSection* options);

void printPerconaDecryptHelp(std::ostream* out);

/**
 * Handle options that should come before validation, such as "help".
 *
 * Returns false if an option was found that implies we should prematurely exit with success.
 */
bool handlePreValidationPerconaDecryptOptions(const moe::Environment& params);

Status storePerconaDecryptOptions(const moe::Environment& params,
                               const std::vector<std::string>& args);
}

==> percona-server-mongodb_4.2.25.orig.tar.gz: percona-server-mongodb-4.2.25-25/src/mongo/tools/perconadecrypt_options.h <==
/*======
This file is part of Percona Server for MongoDB.

Copyright (C) 2019-present Percona and/or its affiliates. All rights reserved.

    This program is free software: you can redistribute it and/or modify
    it under the terms of the Server Side Public License, version 1,
    as published by MongoDB, Inc.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    Server Side Public License for more details.

    You should have received a copy of the Server Side Public License
    along with this program. If not, see
    <http://www.mongodb.com/licensing/server-side-public-license>.

    As a special exception, the copyright holders give permission to link the
    code of portions of this program with the OpenSSL library under certain
    conditions as described in each individual source file and distribute
    linked combinations including the program with the OpenSSL library. You
    must comply with the Server Side Public License in all respects for
    all of the code used other than as permitted herein. If you modify file(s)
    with this exception, you may extend this exception to your version of the
    file(s), but you are not obligated to do so. If you do not wish to do so,
    delete this exception statement from your version. If you delete this
    exception statement from all source files in the program, then also delete
    it in the license file.
======= */

#pragma once

#include <vector>

#include "mongo/base/status.h"

namespace mongo {

namespace optionenvironment {
class OptionSection;
class Environment;
}  // namespace optionenvironment

namespace moe = mongo::optionenvironment;

struct PerconaDecryptGlobalParams {
    std::string inputPath;
    std::string outputPath;

    PerconaDecryptGlobalParams() = default;
};

extern PerconaDecryptGlobalParams perconaDecryptGlobalParams;

Status addPerconaDecryptOptions(moe::OptionSection* options);

void printPerconaDecryptHelp(std::ostream* out);

/**
 * Handle options that should come before validation, such as "help".
 *
 * Returns false if an option was found that implies we should prematurely exit with success.
 */
bool handlePreValidationPerconaDecryptOptions(const moe::Environment& params);

Status storePerconaDecryptOptions(const moe::Environment& params,
                               const std::vector<std::string>& args);

inline Status validateEncryptionCipherModeSetting(const std::string& value) {
    constexpr auto kCBC = "AES256-CBC"_sd;
    constexpr auto kGCM = "AES256-GCM"_sd;

    if (!kCBC.equalCaseInsensitive(value) && !kGCM.equalCaseInsensitive(value)) {
        return {ErrorCodes::BadValue,
                "--encryptionCipherMode expects either 'AES256-CBC' or 'AES256-GCM'"};
    }

    return Status::OK();
}

}
